"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var graphql_1 = require("graphql");
var utils_1 = require("./utils");
function buildInfoForAllScalars(rootFieldName, schema, operation) {
    var fieldNodes = [];
    var type = utils_1.getTypeForRootFieldName(rootFieldName, operation, schema);
    if (type instanceof graphql_1.GraphQLObjectType) {
        var fields_1 = type.getFields();
        var selections = Object.keys(fields_1)
            .filter(function (f) { return utils_1.isScalar(fields_1[f].type); })
            .map(function (fieldName) {
            var field = fields_1[fieldName];
            return {
                kind: 'Field',
                name: { kind: 'Name', value: field.name },
            };
        });
        var fieldNode = {
            kind: 'Field',
            name: { kind: 'Name', value: rootFieldName },
            selectionSet: { kind: 'SelectionSet', selections: selections },
        };
        fieldNodes.push(fieldNode);
    }
    var parentType = operation === 'query' ? schema.getQueryType() : schema.getMutationType();
    return {
        fieldNodes: fieldNodes,
        fragments: {},
        schema: schema,
        fieldName: rootFieldName,
        returnType: type,
        parentType: parentType,
        path: undefined,
        rootValue: null,
        operation: {
            kind: 'OperationDefinition',
            operation: operation,
            selectionSet: { kind: 'SelectionSet', selections: [] },
        },
        variableValues: {},
    };
}
exports.buildInfoForAllScalars = buildInfoForAllScalars;
function buildInfoFromFragment(rootFieldName, schema, operation, query) {
    var type = utils_1.getTypeForRootFieldName(rootFieldName, operation, schema);
    var fieldNode = {
        kind: 'Field',
        name: { kind: 'Name', value: rootFieldName },
        selectionSet: extractQuerySelectionSet(query),
    };
    return {
        fieldNodes: [fieldNode],
        fragments: {},
        schema: schema,
        fieldName: rootFieldName,
        returnType: type,
        parentType: schema.getQueryType(),
        path: undefined,
        rootValue: null,
        operation: {
            kind: 'OperationDefinition',
            operation: operation,
            selectionSet: { kind: 'SelectionSet', selections: [] },
        },
        variableValues: {},
    };
}
exports.buildInfoFromFragment = buildInfoFromFragment;
function extractQuerySelectionSet(query) {
    var document = graphql_1.parse(query);
    var queryNode = document.definitions[0];
    if (!queryNode ||
        queryNode.kind !== 'OperationDefinition' ||
        queryNode.operation !== 'query') {
        throw new Error("Invalid query: " + query);
    }
    return queryNode.selectionSet;
}
//# sourceMappingURL=info.js.map